package afterburner.view.game
{
	import afterburner.model.CollisionModel;
	import afterburner.model.ModelList;
	import afterburner.view.ViewList;
	import afterburner.view.game.engine.GameDisplay3D;
	import afterburner.view.game.stage3D.EnnemisManager;
	import afterburner.view.game.stage3D.ExplosionManager;
	import afterburner.view.game.stage3D.Interface3D;
	import afterburner.view.game.stage3D.RocketManager;
	
	
	import flash.display.DisplayObject;
	import flash.events.Event;
	
	
	import net.pixlib.plugin.PXPlugin;
	import net.pixlib.quick.PXQuick;
	import net.pixlib.view.PXContainerView;
	
	
	import starling.core.Starling;
	import starling.events.Event;
	
	


	/**
	 * @author Matthieu
	 */
	public class Stage3DView extends PXContainerView
	{
		private var oEnnemisManager : EnnemisManager;
		private var oRocketManager : RocketManager;
		private var oInterface : Interface3D;
		private var oExplosionManager : ExplosionManager;
		private var oCollision : CollisionModel;
		private var oStarling : Starling;

		public function Stage3DView(owner : PXPlugin = null, mc : DisplayObject = null)
		{
			super(owner, ViewList.STAGE_3D, mc);
		}


		/**
		 * Appel auto après l'instanciation d'une abstractUI.
		 * 
		 */
		override protected function onInitView() : void
		{
			//hide();
			show();
		}


		/**
		 * Appel par un évènement AppliModel après le chargement des éléments graphiques.
		 * 
		 * content pour récupérer le DisplayObject en cours.
		 * 
		 */
		public function onAssetsLoadComplete(event : flash.events.Event) : void
		{
			logger.debug(" Stage3DView onAssetsLoadComplete ", this);
			
			// avec Stage3D, calcul avec le GPU
			oStarling = new Starling(GameDisplay3D, PXQuick.root.stage);// utilisation de Starling Framework		
			
			// sans Stage3D, calcul uniquement par le CPU		
			//oStarling = new Starling(GameDisplay3D, PXQuick.root.stage, null, null, "software");

			oStarling.antiAliasing = 0; // anti crénelage  (une meilleure qualité réduit les performances de rendu)
			oStarling.simulateMultitouch = false;
			oStarling.showStats = true;
			oStarling.start();


			oEnnemisManager =  EnnemisManager(PXQuick.getView(ViewList.STAGE_3D_ENNEMIS) );
			oRocketManager = RocketManager(PXQuick.getView(ViewList.STAGE_3D_ROCKETS) );
			oExplosionManager = ExplosionManager(PXQuick.getView(ViewList.STAGE_3D_EXPLOSIONS) );
			oInterface = Interface3D(PXQuick.getView(ViewList.STAGE_3D_INTERFACE) );
			oCollision = CollisionModel( PXQuick.getModel(ModelList.COLLISIONS) );
		}
		
		
		/**
		 * Appel par une commande.
		 * 
		 */
		public function onStartGame() : void
		{
			// écouteur sur chaque image par seconde
			oStarling.stage.addEventListener(starling.events.Event.ENTER_FRAME, onFrame);
		}
		
		
		/**
		 * Appel par une commande.
		 * 
		 */
		public function onStopGame() : void
		{
			// écouteur sur chaque image par seconde
			oStarling.stage.removeEventListener(starling.events.Event.ENTER_FRAME, onFrame);
		}



		/**
		 * Mets à jour les éléments du jeu.
		 * 
		 */
		private function onFrame(event : starling.events.Event) : void
		{
			oEnnemisManager.update(event);// mise à jour de la position des ennemis
			oRocketManager.update();// mise à jour de la position des balles
			oCollision.update();
			oExplosionManager.update();
			oInterface.update();
		}

	}
}