/**

  The Initial Developer of the Original Code is
  Matthieu  - http://www.actionscript-facile.com
  Portions created by the Initial Developer are Copyright (C) 2010
  the Initial Developer. All Rights Reserved.

  Contributor(s) :

 */
package afterburner.view.game.engine.elements
{
	import starling.core.Starling;
	import starling.display.MovieClip;
	import starling.textures.Texture;	
	
	
	import afterburner.view.util.MathUtils;


	/**
	 * Gestion des caractéristiques d'une ennemis.
	 * 
	 */
	public class Ennemis
	{
		private var oMovie:MovieClip = null;
		
		private var nSpeed : int;
		
		private var offset : Number;
		private var sign : int;
		private var startX : Number;
		private var waveLength : Number;
		private var frequency : Number = 100;
				
				
				
		/**
		 * Constructeur.
		 * Ajoute un ennemi positionné aléatoirement.
		 * 
		 */
		public function Ennemis(frames:Vector.<Texture>, name:String, iWidth:int)
		{
			this.init(frames, name, iWidth);
		}
		
		
		/**
		 * Init de la création de l'ennemi.
		 * 
		 */
		private function init(frames:Vector.<Texture>, name:String, iWidth:int) : void
		{
			/* init de l'ennemis */
			oMovie = new MovieClip(frames, 60);
			oMovie.name = name;
			Starling.juggler.add ( oMovie );
			
			oMovie.y = - oMovie.height*2;
			
			startX = MathUtils.randomInt(0, iWidth);
			oMovie.x = startX;
			nSpeed = MathUtils.randomInt(5, 13);
			
			offset = Math.random() * 100;
			sign = MathUtils.randomPlusMinus();
			waveLength = Math.random() * 100;
		}


		/**
		 * Renvoie le clip pour ajout sur la scène
		 */
		public function get clip() : MovieClip {return oMovie;}
		
		
		
		/**
		 * Mise à jour du mouvement de l'ennemis.
		 * 
		 */
		public function update() : void
		{
			// progression de l'ennemi
			oMovie.y += nSpeed;
			
			// effet zig zag
			oMovie.x = startX + Math.sin(oMovie.y / frequency) * waveLength;
			
			// changement de direction
			oMovie.rotation = Math.sin( (oMovie.y*0.02) + offset ) * 0.1 * sign;
			if( oMovie.rotation < 0 )	oMovie.rotation *= -1;	
			
			// effet de respiration sur l'ennemis
			oMovie.scaleX = 1 + oMovie.rotation * 0.5;
			oMovie.scaleY = 1 + oMovie.rotation * 0.5;
		}

		
		/**
		 * Supprime les ressources graphiques utilisées par l'ennemis.
		 * 
		 */
		private function remove() : void
		{
			if( oMovie != null )
			{
				Starling.juggler.remove ( oMovie );
				oMovie.removeFromParent(true);
				oMovie = null; 
			}
			
		}


		/**
		 * Supprime les ressources utilisées par l'ennemis.
		 * 
		 */
		public function dispose() : void
		{
			this.remove();
		}
		
	}
}